@@ -2,7 +2,7 @@
 #' @import AzureGraph
 NULL
 
-utils::globalVariables(c("self", "private"))
+utils::globalVariables(c("self", "private", "super", "get_paged_list"))
 
 .az_cli_app_id <- "04b07795-8ddb-461a-bbee-02f9e1bf7b46"
 
